{ config, pkgs, ... }:

let
  colors = import ../colors;
in
{
  services = {
   xserver = {
      enable = true;
      xkbOptions = "caps:escape";
      displayManager = {
        lightdm = {
          enable = true;
          greeters.gtk = {
            enable = true;
            theme = {
              name = "Nordic";
              package = pkgs.nordic;
            };
          };
          background = ../wallpapers/${colors.wallpaper};
        };
        defaultSession = "none+i3";
      };
      windowManager.i3 = {
        enable = true;
        package = pkgs.i3-gaps;
      };
    };
    udev.packages = [ pkgs.yubikey-personalization ];
    pcscd.enable = true;
    gnome.gnome-keyring.enable = true; # For remembering nextcloud login, among other things
  };

  environment.systemPackages = with pkgs; [ yubioath-flutter ];

  # Enable OpenTabletDriver, GUI configurator is otd-gui
  hardware.opentabletdriver.enable = true;

  # To prevent `Unit dconf.service not found.` after theming GTK in HM
  programs.dconf.enable = true;

  sound.enable = true;
  hardware.pulseaudio.enable = true;
  nixpkgs.config.pulseaudio = true;

  fonts = {
    enableDefaultFonts = false;
    fonts = with pkgs; [
      # noto-fonts-cjk doesn't display in Discord for some reason
      # mplus-outline-fonts.osdnRelease is no longer updated and is now mplus-outline-fonts.githubRelease,
      # but で renders weird for some reason in the GitHub release, so I'm sticking to OSDN
      mplus-outline-fonts.osdnRelease
      noto-fonts
      (nerdfonts.override { fonts = [ "FiraCode" ]; }) # required for icons
    ];
  };
}
